<?php

/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */

namespace Webkul\SalesforceConnector\Block\Adminhtml\System\Config;

class RecordContact extends \Magento\Config\Block\System\Config\Form\Field
{

    // protected $_data;
    protected $_helper;
    protected $_json;
    protected $recordContact;

    public function __construct(
        // \Webkul\SalesforceConnector\Helper\Data $data,
        \Magento\Backend\Block\Template\Context $context,
        \Webkul\SalesforceConnector\Helper\Connection $helper,
        \Magento\Framework\App\Helper\Context $helperContext,
        \Webkul\SalesforceConnector\Model\Config\Source\RecordCon $recordContact,
        \Magento\Framework\Json\Helper\Data $jsonHelper,
        array $data = []
    ) {
        // $this->_data = $data;
        parent::__construct($context, $data);
        $this->_helper = $helper;
        $this->_json = $jsonHelper;
        $this->recordContact = $recordContact;
        $this->_scopConfig = $helperContext->getScopeConfig();
    }
    protected function _prepareLayout()
    {
        parent::_prepareLayout();
        if (!$this->getTemplate()) {
            $this->setTemplate('Webkul_SalesforceConnector::system/config/recordCon.phtml');
        }
        return $this;
    }

    /**
     * Unset some non-related element parameters
     *
     * @param \Magento\Framework\Data\Form\Element\AbstractElement $element
     * @return string
     */
    public function render(\Magento\Framework\Data\Form\Element\AbstractElement $element)
    {
        $element->unsScope()->unsCanUseWebsiteValue()->unsCanUseDefaultValue();
        return parent::render($element);
    }

    /**
     * Get the button and scripts contents
     *
     * @param \Magento\Framework\Data\Form\Element\AbstractElement $element
     * @return string
     */
    protected function _getElementHtml(\Magento\Framework\Data\Form\Element\AbstractElement $element)
    {
        return $this->_toHtml();
    }
    public function getRecordContact()
    {
        $recordContact = $this->_scopConfig
            ->getValue(
                'sfConnect/accCon/recordCon',
                \Magento\Store\Model\ScopeInterface::SCOPE_STORE
            );
        if ($recordContact) {
            return $this->_json->jsonDecode($recordContact)['name'];
        } else {
            return 0;
        }
    }
    public function getRecordContactId()
    {
        $recordContact = $this->_scopConfig
            ->getValue(
                'sfConnect/accCon/recordCon',
                \Magento\Store\Model\ScopeInterface::SCOPE_STORE
            );
        if ($recordContact) {
            return $this->_json->jsonDecode($recordContact)['id'];
        } else {
            return 0;
        }
    }
    public function getRecordContactList()
    {
        return $this->recordContact->toOptionArray();
    }
    public function getOrgId()
    {
        if (isset($this->_helper->_sfconfigData['orgDetails']) && isset($this->_helper->_sfconfigData['orgDetails']['Id'])) {
            return $this->_helper->_sfconfigData['orgDetails']['Id'];
        } else {
            return '';
        }
    }
    public function getOrgName()
    {
        if (isset($this->_helper->_sfconfigData['orgDetails']) && isset($this->_helper->_sfconfigData['orgDetails']['Name'])) {
            return $this->_helper->_sfconfigData['orgDetails']['Name'];
        } else {
            return '';
        }
    }
    public function getConnUserName()
    {
        if (isset($this->_helper->_sfconfigData['userName']) && isset($this->_helper->_sfconfigData['userName']['Username'])) {
            return $this->_helper->_sfconfigData['userName']['Username'];
        } else {
            return '';
        }
    }
    public function getConnUser()
    {
        if (isset($this->_helper->_sfconfigData['userName']) && isset($this->_helper->_sfconfigData['userName']['Name'])) {
            return $this->_helper->_sfconfigData['userName']['Name'];
        } else {
            return '';
        }
    }
    public function getConnUserEmail()
    {
        if (isset($this->_helper->_sfconfigData['userName']) && isset($this->_helper->_sfconfigData['userName']['Email'])) {
            return $this->_helper->_sfconfigData['userName']['Email'];
        } else {
            return '';
        }
    }
}
