<?php

/**
 * Webkul Software.
 *
 * @category  Webkul
 *
 * @author    Webkul Software Private Limited
 * @copyright Copyright (c) 2010-2017 Webkul Software Private Limited (https://webkul.com)
 * @license   https://store.webkul.com/license.html
 */

namespace Webkul\SalesforceConnector\Controller\Adminhtml\Customers;

use Webkul\SalesforceConnector\Helper\Customer;

class CustSync extends \Magento\Backend\App\Action
{
    /** @var \Magento\Framework\View\Result\PageFactory */
    protected $_resultPageFactory;
    // protected $_categoryCollection;
    protected $_filter;
    protected $_helper;
    protected $_helperData;
    /**
     * @var CollectionFactory
     */
    protected $_collectionFactory;

    /**
     * @param \Magento\Backend\App\Action\Context        $context
     * @param \Magento\Framework\View\Result\PageFactory $resultPageFactory
     */
    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        \Magento\Framework\View\Result\PageFactory $resultPageFactory,
        \Magento\Ui\Component\MassAction\Filter $filter,
        \Magento\Customer\Model\ResourceModel\Customer\CollectionFactory $collectionFactory,
        Customer $helper
    ) {
        parent::__construct($context);
        $this->_resultPageFactory = $resultPageFactory;

        $this->_helper = $helper;
        $this->_collectionFactory = $collectionFactory;
        $this->_filter = $filter;
    }

    public function execute()
    {
        if (\Webkul\SalesforceConnector\Helper\Connection::checkConnectionStatus()) {
            $id = $this->getRequest()->getParam('entity_id');          
            if ($id) {
                $sfId = $this->_helper->exportSpecificCustomer($id);
                if ($sfId) {
                    $this->messageManager
                        ->addSuccess(__('Customer has been successfully Exported at Salesforce.', $sfId));
                }
            } else {
                $ids = $this->getRequest()->getParam('selected');
                $success=0;
                if ($ids) {
                    $ids=array_chunk($ids,4);
                    foreach($ids as $id){
                        $success += $this->_helper->exportCustomers($id)['success'];
                    }                        
                    $this->messageManager->addSuccess(
                        __('A total of %1 record(s) have been processed.', $success)
                    );
                } else {
                    
                    $excludedIds = $this->getRequest()->getParam('excluded');
                    $collection = $this->_collectionFactory->create();
                    $allCustomerIds=array();
                    foreach ($collection->getItems() as $item) {
                        array_push($allCustomerIds, $item->getID());
                    }                  
                    if ($excludedIds=='false') {
                        $allCustomerIds=array_chunk($allCustomerIds,4);
                        foreach($allCustomerIds as $id){
                            $success += $this->_helper->exportCustomers($id)['success'];
                        }  
                        $this->messageManager->addSuccess(
                            __('A total of %1 record(s) have been processed.', $success)
                        );
                    } else {
                        $ids=array_diff($allCustomerIds, $excludedIds);    
                        $ids=array_chunk($ids,4);
                        foreach($ids as $id){
                            $success += $this->_helper->exportCustomers($id)['success'];
                        }                          
                        $this->messageManager->addSuccess(
                            __('A total of %1 record(s) have been processed.', $success)
                        );
                    }
                }
            }
        } else {
            $this->messageManager
            ->addError(__('Check Connection'));
        }
        $resultRedirect = $this->resultRedirectFactory->create();
        $resultRedirect->setPath('sfconnector/customers/index/');

        return $resultRedirect;
    }
}
