<?php

/**
 * Webkul Software.
 *
 * @category  Webkul
 *
 * @author    Webkul Software Private Limited
 * @copyright Copyright (c) 2010-2017 Webkul Software Private Limited (https://webkul.com)
 * @license   https://store.webkul.com/license.html
 */

namespace Webkul\SalesforceConnector\Controller\Adminhtml\Products;

use Webkul\SalesforceConnector\Helper\Product;

class Pdtsync extends \Magento\Backend\App\Action
{
    /** @var \Magento\Framework\View\Result\PageFactory */
    protected $_resultPageFactory;
    // protected $_categoryCollection;
    /**
     * Massactions filter.
     *
     * @var Filter
     */
    protected $_filter;

    /**
     * @var CollectionFactory
     */
    protected $_collectionFactory;
    protected $_helper;
    protected $_helperData;

    /**
     * @param \Magento\Backend\App\Action\Context        $context
     * @param \Magento\Framework\View\Result\PageFactory $resultPageFactory
     */
    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        \Magento\Framework\View\Result\PageFactory $resultPageFactory,
        \Magento\Ui\Component\MassAction\Filter $filter,
        \Magento\Catalog\Model\ResourceModel\Product\CollectionFactory $collectionFactory,
        Product $helper
    ) {
        parent::__construct($context);
        $this->_resultPageFactory = $resultPageFactory;
        $this->_helper = $helper;
        $this->_filter = $filter;
        $this->_collectionFactory = $collectionFactory;
    }

    public function execute()
    {   
        
        if (\Webkul\SalesforceConnector\Helper\Connection::checkConnectionStatus()) {
            $id = $this->getRequest()->getParam('entity_id');
            if ($id) {
                $sfId = $this->_helper->syncSpecificProduct($id);
                if ($sfId) {
                    $this->messageManager
                    ->addSuccess(__('Product has been successfully Exported at Salesforce.', $sfId));
                }
            } else {
                $success=0;
                $ids = $this->getRequest()->getParam('selected');
               
                if ($ids) {
                    $ids=array_chunk($ids,4);
                    
                    foreach($ids as $id){
                        
                        $exportData=$this->_helper->exportProducts($id);
                        if(isset($exportData['error'])){
                            $this->messageManager
                                 ->addError(__($exportData['error']));
                            break;     
                        }
                        else{
                        $success+=$exportData[0];
                        }
                    }
                    $this->messageManager->addSuccess(
                        __('A total of %1 record(s) have been processed.', $success)
                    );
                } else {
                    $excludedIds = $this->getRequest()->getParam('excluded');
                    $collection = $this->_collectionFactory->create();
                    $allProductIds=array();
                    foreach ($collection->getItems() as $item) {
                        array_push($allProductIds, $item->getID());
                    }                  
                    if ($excludedIds=='false') {
                        $allProductIds=array_chunk($allProductIds,4);
                        foreach($allProductIds as $id){
                            
                            $exportData=$this->_helper->exportProducts($id);
                            if(isset($exportData['error'])){
                                $this->messageManager
                                     ->addError(__($exportData['error']));
                                break;     
                            }
                            else{
                            $success+=$exportData[0];
                            }
                        }
                        $this->messageManager->addSuccess(
                            __('A total of %1 record(s) have been processed.', $success)
                        );
                    } else {
                        $ids=array_diff($allProductIds, $excludedIds);     
                        $ids=array_chunk($ids,4);
                        foreach($ids as $id){
                            $exportData=$this->_helper->exportProducts($id);
                            if(isset($exportData['error'])){
                                $this->messageManager
                                     ->addError(__($exportData['error']));
                                break;     
                            }
                            else{
                            $success+=$exportData[0];
                            }
                        }                  
                        $this->messageManager->addSuccess(
                            __('A total of %1 record(s) have been processed.', $success)
                        );
                    }
                }
            }
        } else {
            $this->messageManager
                ->addError(__('Check Connection.'));
        }

        $resultRedirect = $this->resultRedirectFactory->create();
        $resultRedirect->setPath('sfconnector/products/index/');

        return $resultRedirect;
    }
}
